conntest

package
v1.7.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 9, 2026 License: BSD-3-Clause Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func TestClusters

func TestClusters(r RoutingDialer, clusters []lieutenant.Cluster) iter.Seq[Report]

TestClusters tests the connectivity to the API server, console and OAuth endpoint of the given clusters using the provided HTTP client. It returns a channel of reports for each cluster.

Types

type Report

type Report struct {
	ClusterName string

	SkippedReason string

	Jumphost string

	ConsoleURL             string
	ConsoleConnectionErr   error
	APIServerURL           string
	APIServerConnectionErr error
	OAuthURL               string
	OAuthConnectionErr     error

	Warnings []string
}

func (Report) HasErrors

func (r Report) HasErrors() bool

func (Report) Skipped

func (r Report) Skipped() bool

type RoutingDialer

type RoutingDialer interface {
	DialContext(ctx context.Context, network, address string) (net.Conn, error)
	JumphostForHost(host string) string
}

Jump to