proxy

package
v0.0.1-dev1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 4, 2026 License: BSD-3-Clause Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Proxy

type Proxy struct {
	// SSHConfig is the SSH config to use for determining jumphosts and SSH connection settings.
	// If not set, the proxy uses ssh_config.DefaultUserSettings.
	SSHConfig *ssh_config.UserSettings

	// DirectDialer is the dialer to use for direct connections.
	DirectDialer net.Dialer

	// KeepAliveInterval is the interval for sending keep-alive messages to the jumphosts.
	// Defaults to 3 seconds if not set.
	KeepAliveInterval time.Duration
}

func (*Proxy) Start

func (p *Proxy) Start(ctx context.Context, addr, mappingFile string) error

Jump to