Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func TestClusters ¶
func TestClusters(r RoutingDialer, clusters []lieutenant.Cluster) iter.Seq[Report]
TestClusters tests the connectivity to the API server, console and OAuth endpoint of the given clusters using the provided HTTP client. It returns a channel of reports for each cluster.
Types ¶
Click to show internal directories.
Click to hide internal directories.